@@ -1,5 +1,6 @@
 /*
- * Copyright 2011  Rodrigo Belem <rclbelem@gmail.com>
+ * Copyright (c) 2011 Rodrigo Belem <rclbelem@gmail.com>
+ * Copyright (c) 2019 Nate Graham <nate@kde.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -36,8 +37,6 @@ public:
     void setEditorData(QWidget *editor, const QModelIndex &index) const;
     void setModelData(QWidget *editor, QAbstractItemModel *model,
                       const QModelIndex &index) const;
-private Q_SLOTS:
-    void emitCommitData();
 };
 
 #endif
